@@ -502,6 +502,10 @@ class TestIntrospection(ModelTestCase):
         self.assertTrue(self.database.table_exists(User._meta.table_name))
         self.assertFalse(self.database.table_exists('nuggies'))
 
+        self.assertTrue(self.database.table_exists(User))
+        class X(TestModel): pass
+        self.assertFalse(self.database.table_exists(X))
+
     def test_get_tables(self):
         tables = self.database.get_tables()
         required = set(m._meta.table_name for m in self.requires)
@@ -730,6 +734,29 @@ class TestDBProxy(BaseTestCase):
         with_manual_commit()
         self.assertFalse(db.in_transaction())
 
+    def test_proxy_bind_ctx_callbacks(self):
+        db = Proxy()
+        class BaseModel(Model):
+            class Meta:
+                database = db
+
+        class Hook(BaseModel):
+            data = BlobField()  # Attaches hook to configure blob-type.
+
+        self.assertTrue(Hook.data._constructor is bytearray)
+
+        class CustomSqliteDB(SqliteDatabase):
+            sentinel = object()
+            def get_binary_type(self):
+                return self.sentinel
+
+        custom_db = CustomSqliteDB(':memory:')
+
+        with custom_db.bind_ctx([Hook]):
+            self.assertTrue(Hook.data._constructor is custom_db.sentinel)
+
+        self.assertTrue(Hook.data._constructor is bytearray)
+
 
 class Data(TestModel):
     key = TextField()
