@@ -247,9 +247,11 @@ class TestDateFields(ModelTestCase):
             self.assertEqual(row,
                              (2011, 1, 2, 11, 12, 13, 2012, 2, 3, 3, 13, 37))
         else:
-            self.assertEqual(row, (
-                2011., 1., 2., 11., 12., 13.054321, 2012., 2., 3., 3., 13.,
-                37.))
+            self.assertTrue(row in [
+                (2011., 1., 2., 11., 12., 13.054321, 2012., 2., 3., 3., 13.,
+                 37.),
+                (D('2011'), D('1'), D('2'), D('11'), D('12'), D('13.054321'),
+                 D('2012'), D('2'), D('3'), D('3'), D('13'), D('37'))])
 
     def test_truncate_date(self):
         dm = DateModel.create(
@@ -1287,6 +1289,19 @@ class TestForeignKeyLazyLoad(ModelTestCase):
             b = NQ.create(name='b')
             bi = NQItem.create(nq=b, nq_lazy=b)
 
+    def test_doesnotexist_lazy_load(self):
+        n = NQ.create(name='n1')
+        i = NQItem.create(nq=n, nq_null=n, nq_lazy=n, nq_lazy_null=n)
+
+        i_db = NQItem.select(NQItem.id).where(NQItem.nq == n).get()
+        with self.assertQueryCount(0):
+            # Only raise DoesNotExist for non-nullable *and* lazy-load=True.
+            # Otherwise we just return None.
+            self.assertRaises(NQ.DoesNotExist, lambda: i_db.nq)
+            self.assertTrue(i_db.nq_null is None)
+            self.assertTrue(i_db.nq_lazy is None)
+            self.assertTrue(i_db.nq_lazy_null is None)
+
     def test_foreign_key_lazy_load(self):
         a1, a2, a3, a4 = (NQ.select()
                           .where(NQ.name.startswith('a'))
